;; Generated package description from mmm-mode.el  -*- no-byte-compile: t -*-
(define-package "mmm-mode" "0.5.8.0.20200908.223625" "Allow Multiple Major Modes in a buffer" '((cl-lib "0.2")) :keywords '("convenience" "faces" "languages" "tools") :authors '(("Michael Abraham Shulman" . "viritrilbia@gmail.com")) :maintainer '("Dmitry Gutov" . "dgutov@yandex.ru") :url "https://github.com/purcell/mmm-mode")
